38#include <hip/hip_runtime.h>
50 void *
vx,
void *
vy,
void *
vz,
51 void *
dx,
void *
dy,
void *
dz,
64 void *
vx,
void *
vy,
void *
vz,
65 void *
dx,
void *
dy,
void *
dz,
69 void *
jacinv,
int *nel,
int *gdim,
int *lx) {
81#define CASE_1D(LX, C) \
82 hipLaunchKernelGGL( HIP_KERNEL_NAME( \
83 conv1_kernel_1d<real, LX, NEKO_CHUNKS(LX, C)> ), \
84 nblcks, NEKO_CHUNKS_NTHRDS(LX, C), 0, \
85 (hipStream_t) glb_cmd_queue, \
86 (real *) du, (real *) u, \
87 (real *) vx, (real *) vy, (real *) vz, \
88 (real *) dx, (real *) dy, (real *) dz, \
89 (real *) drdx, (real *) dsdx, (real *) dtdx, \
90 (real *) drdy, (real *) dsdy, (real *) dtdy, \
91 (real *) drdz, (real *) dsdz, (real *) dtdz, \
93 HIP_CHECK(hipGetLastError());
96#define CASE_1D_SEL(LX, SEL) \
98 case 0: CASE_1D(LX, 0); break; \
99 case 1: CASE_1D(LX, 1); break; \
100 case 2: CASE_1D(LX, 2); break; \
101 default: CASE_1D(LX, 3); break; \
104#define CASE_KSTEP(LX, C) \
105 hipLaunchKernelGGL( HIP_KERNEL_NAME( \
106 conv1_kernel_kstep<real, LX, NEKO_EB(LX, C)> ), \
107 NEKO_EB_NBLCKS(*nel, LX, C), NEKO_EB_NTHRDS(LX, C), 0, \
108 (hipStream_t) glb_cmd_queue, \
109 (real *) du, (real *) u, \
110 (real *) vx, (real *) vy, (real *) vz, \
111 (real *) dx, (real *) dy, (real *) dz, \
112 (real *) drdx, (real *) dsdx, (real *) dtdx, \
113 (real *) drdy, (real *) dsdy, (real *) dtdy, \
114 (real *) drdz, (real *) dsdz, (real *) dtdz, \
115 (real *) jacinv, *nel); \
116 HIP_CHECK(hipGetLastError());
119#define CASE_KSTEP_SEL(LX, SEL) \
121 case 0: CASE_KSTEP(LX, 0); break; \
122 case 1: CASE_KSTEP(LX, 1); break; \
123 default: CASE_KSTEP(LX, 2); break; \
128 if(autotune[LX] == 0 ) { \
129 autotune[LX]=tune_conv1<LX>(du, u, \
135 jacinv, nel, gdim, lx, &autotune_eb[LX], \
137 } else if (autotune[LX] == 1 ) { \
138 CASE_1D_SEL(LX, autotune_ch[LX]); \
139 } else if (autotune[LX] == 2 ) { \
140 CASE_KSTEP_SEL(LX, autotune_eb[LX]); \
144#define CASE_LARGE(LX) \
186template < const
int LX >
188 void *
vx,
void *
vy,
void *
vz,
189 void *
dx,
void *
dy,
void *
dz,
268 for (
int r = 0; r <
rounds; r++) {
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ vz
__global__ void const T *__restrict__ const T *__restrict__ vx
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ vy
#define NEKO_CHUNKS_CANDIDATES
#define NEKO_EB_CANDIDATES
#define NEKO_EB_SEL(LX, SEL)
#define NEKO_CHUNKS_SEL(LX, SEL)
#define NEKO_TUNE_TIME(T, LAUNCH, LX, C, ITERS)
static int neko_tune_rounds()
#define NEKO_TUNE_LOG(LX, T1, T2)
#define NEKO_TUNE_BEST(T, BEST, N)
static int neko_tune_iters()
static int neko_chunks_env()
static int neko_eb_sweep()
void log_error(char *msg)
void log_message(char *msg)
void log_section(char *msg)
int tune_conv1(void *du, void *u, void *vx, void *vy, void *vz, void *dx, void *dy, void *dz, void *drdx, void *dsdx, void *dtdx, void *drdy, void *dsdy, void *dtdy, void *drdz, void *dsdz, void *dtdz, void *jacinv, int *nel, int *gdim, int *lx, int *eb_sel, int *ch_sel)
#define CASE_KSTEP_SEL(LX, SEL)
#define CASE_1D_SEL(LX, SEL)
void hip_conv1(void *du, void *u, void *vx, void *vy, void *vz, void *dx, void *dy, void *dz, void *drdx, void *dsdx, void *dtdx, void *drdy, void *dsdy, void *dtdy, void *drdz, void *dsdz, void *dtdz, void *jacinv, int *nel, int *gdim, int *lx)
#define CASE_KSTEP(LX, C)